@@ -26,7 +26,7 @@ def country(country):
   temperatures["City"] = capital
   return temperatures
 
-def main():
+def cli():
   fire.Fire({
       'city': city,
       'country': country
